# -*- coding: utf-8 -*-
from flask_wtf.form import Form
from wtforms.fields import *  # be more explicit after generating forms
from wtforms import validators as val


